@@ -4,7 +4,7 @@
  *
  * PHP Version 5
  *
- * Copyright (c) 2008-2015, Manuel Pichler <mapi@pdepend.org>.
+ * Copyright (c) 2008-2017 Manuel Pichler <mapi@pdepend.org>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 
@@ -47,18 +47,11 @@ use PDepend\Source\ASTVisitor\ASTVisitor;
 /**
  * Represents a php namespace node.
  *
- * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 class ASTNamespace extends AbstractASTArtifact
 {
-    /**
-     * The namespace name.
-     *
-     * @var string
-     */
-    protected $name = '';
-
     /**
      * The unique identifier for this function.
      *
@@ -89,6 +82,11 @@ class ASTNamespace extends AbstractASTArtifact
      */
     private $userDefined = null;
 
+    /**
+     * @var boolean
+     */
+    protected $packageAnnotation = false;
+
     /**
      * Constructs a new namespace for the given <b>$name</b>
      *
@@ -96,20 +94,10 @@ class ASTNamespace extends AbstractASTArtifact
      */
     public function __construct($name)
     {
-        $this->name = $name;
+        parent::__construct($name);
         $this->id = spl_object_hash($this);
     }
 
-    /**
-     * Returns the namespace name.
-     *
-     * @return string
-     */
-    public function getName()
-    {
-        return $this->name;
-    }
-
     /**
      * Returns a id for this code node.
      *
@@ -305,6 +293,22 @@ class ASTNamespace extends AbstractASTArtifact
         }
     }
 
+    /**
+     * @return boolean
+     */
+    public function isPackageAnnotation()
+    {
+        return $this->packageAnnotation;
+    }
+
+    /**
+     * @param boolean $packageAnnotation
+     */
+    public function setPackageAnnotation($packageAnnotation)
+    {
+        $this->packageAnnotation = $packageAnnotation;
+    }
+
     /**
      * ASTVisitor method for node tree traversal.
      *
