@@ -4,7 +4,7 @@
  *
  * PHP Version 5
  *
- * Copyright (c) 2008-2015, Manuel Pichler <mapi@pdepend.org>.
+ * Copyright (c) 2008-2017 Manuel Pichler <mapi@pdepend.org>.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -36,7 +36,7 @@
  * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
  * POSSIBILITY OF SUCH DAMAGE.
  *
- * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 
@@ -63,7 +63,7 @@ use PDepend\Util\Type;
 /**
  * Default code tree builder implementation.
  *
- * @copyright 2008-2015 Manuel Pichler. All rights reserved.
+ * @copyright 2008-2017 Manuel Pichler. All rights reserved.
  * @license http://www.opensource.org/licenses/bsd-license.php BSD License
  */
 class PHPBuilder implements Builder
@@ -364,7 +364,9 @@ class PHPBuilder implements Builder
      */
     public function buildAnonymousClass()
     {
-        return $this->buildAstNodeInstance('ASTAnonymousClass');
+        return $this->buildAstNodeInstance('ASTAnonymousClass')
+            ->setCache($this->cache)
+            ->setContext($this->context);
     }
 
     /**
@@ -1453,7 +1455,18 @@ class PHPBuilder implements Builder
     {
         return $this->buildAstNodeInstance('ASTTypeCallable');
     }
-
+    
+    /**
+     * Builds a new node for the iterable type.
+     *
+     * @return \PDepend\Source\AST\ASTTypeIterable
+     * @since  2.5.1
+     */
+    public function buildAstTypeIterable()
+    {
+        return $this->buildAstNodeInstance('ASTTypeIterable');
+    }
+    
     /**
      * Builds a new primitive type node.
      *
